@@ -1,12 +1,25 @@
-"""control.py
+"""
+MIT License
 
-Returns
--------
-ControlPosition
-    Class to describe a controls position
+Copyright (c) 2020 DashIO-Connect
 
-Control
-    A base class for controls
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
 """
 import copy
 import json
@@ -108,7 +121,7 @@ class Control:
         self._title_position = None
         if title_position is not None:
             self.title_position = title_position
-        self.cntrl_type = cntrl_type
+        self.cntrl_type = cntrl_type.translate(BAD_CHARS)
         self.control_id = control_id.translate(BAD_CHARS)
         self.message_rx_event = Event()
         self.message_tx_event = Event()
@@ -148,7 +161,8 @@ class Control:
 
     @parent_id.setter
     def parent_id(self, val: str):
-        self._cfg["parentID"] = val
+        _val = val.translate(BAD_CHARS)
+        self._cfg["parentID"] = _val
 
     @property
     def control_id(self) -> str:
@@ -178,7 +192,8 @@ class Control:
 
     @title.setter
     def title(self, val: str):
-        self._cfg["title"] = val
+        _val = val.translate(BAD_CHARS)
+        self._cfg["title"] = _val
 
     @property
     def control_position(self) -> ControlPosition:
