@@ -1,5 +1,26 @@
-# pylint: disable=duplicate-code
-"""event_log.py"""
+"""
+MIT License
+
+Copyright (c) 2020 DashIO-Connect
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
 import datetime
 
 import dateutil.parser
@@ -13,28 +34,33 @@ from .ring_buffer import RingBuffer
 class EventData:
     """Event log data point
     """
-    def __init__(self, header: str, body: str, color=Color.WHITE):
+    def __init__(self, lines: str, color=Color.WHITE):
         """EventLog data point
 
         Parameters
         ----------
 
-        header : str
-            Header or title of the data
-        body : str
-            The event data
+        lines : str max 25 lines long. Each line is seperated by '\n'
         color : Color, optional
-            The color tto diplay this data point io iotdashboard app, by default Color.WHITE
+            The color to diplay this data point io iotdashboard app, by default Color.WHITE
         """
         self.color = color
         self.timestamp = datetime.datetime.utcnow().replace(microsecond=0, tzinfo=datetime.timezone.utc)
-        self.header = header.translate(BAD_CHARS)
-        self.body = body.translate(BAD_CHARS)
+        self.event_lines = []
+        no_l = 0
+
+        for s_line in lines.split("\n"):
+            self.event_lines.append(s_line.translate(BAD_CHARS))
+            no_l += 1
+            if no_l > 25:
+                break
 
     def __str__(self):
-        return "{ts}\t{color}\t{header}\t{body}\n".format(
-            ts=self.timestamp.isoformat(), color=str(self.color.value), header=self.header, body=self.body
-        )
+        header = "{ts}\t{color}".format(ts=self.timestamp.isoformat(), color=str(self.color.value))
+        for line in self.event_lines:
+            header += "\t" + line
+        header += "\n"
+        return header
 
 
 class EventLog(Control):
