@@ -1,11 +1,27 @@
-"""graph.py
-
-Returns
--------
-GraphLine
-    A line glass for a grapgh control.
 """
+MIT License
 
+Copyright (c) 2020 DashIO-Connect
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
+from ..constants import BAD_CHARS
 from .control import Control
 from .enums import Color, GraphLineType, GraphXAxisLabelsStyle, TitlePosition
 
@@ -13,7 +29,7 @@ class GraphLine:
     """GraphLine class
     """
     def __init__(self, name="", line_type=GraphLineType.LINE, color=Color.BLACK):
-        self.name = name
+        self.name = name.translate(BAD_CHARS)
         self.line_type = line_type
         self.color = color
         self.data = []
@@ -86,7 +102,7 @@ class Graph(Control):
         gline : GraphLine
             The line to add
         """
-        self.line_dict[line_id] = gline
+        self.line_dict[line_id.translate(BAD_CHARS)] = gline
 
     def send_graph(self):
         """Sends the graph to any connected iotdashboard app.
@@ -109,7 +125,7 @@ class Graph(Control):
 
     @x_axis_label.setter
     def x_axis_label(self, val: str):
-        self._cfg["xAxisLabel"] = val
+        self._cfg["xAxisLabel"] = val.translate(BAD_CHARS)
 
     @property
     def x_axis_min(self) -> float:
@@ -185,7 +201,7 @@ class Graph(Control):
 
     @y_axis_label.setter
     def y_axis_label(self, val: str):
-        self._cfg["yAxisLabel"] = val
+        self._cfg["yAxisLabel"] = val.translate(BAD_CHARS)
 
     @property
     def y_axis_min(self) -> float:
